@@ -18,7 +18,7 @@ bed.merge.inds <- function(x1, x2) {
   bed1 <- .Call('gg_extract_inds_indices', x1@bed, w1) 
   bed2 <- .Call('gg_extract_inds_indices', x2@bed, w2) 
 
-  bed <- .Call("gg_bind_snps",  PACKAGE='gaston', list(bed1, bed2))
+  bed <- .Call("gg_bind_snps",  PACKAGE = "gaston", list(bed1, bed2))
 
   snps <- rbind(x1@snps, x2@snps)
 
